donut.generate

Write code generators that can be executed from the REPL

Write code generators that can be executed from the REPL
raw docstring

->fileclj

(->file n)

Given a string or symbol, presumably representing a namespace, return a string that represents the equivalent file system path.

Given a string or symbol, presumably representing a namespace, return a string
that represents the equivalent file system path.
raw docstring

->nsclj

(->ns f)

Given a string or symbol, presumably representing a file path, return a string that represents the equivalent namespace.

Given a string or symbol, presumably representing a file path, return a string
that represents the equivalent namespace.
raw docstring

->subst-mapclj

(->subst-map substitutions)

Given a hash map of substitution data, return a hash map of string substitutions. For any unqualified keys that have string or symbol values, compute a |ns version that could be used as a namespace and a |file version that could be used as a filename. These are done fairly simply as seen above.

Given a hash map of substitution data, return a hash map of string
substitutions. For any unqualified keys that have string or symbol values,
compute a `|ns` version that could be used as a namespace and a `|file`
version that could be used as a filename. These are done fairly simply as seen
above.
raw docstring

append-child-newlineclj

(append-child-newline loc _)

Contentclj


find-pathclj

(find-path loc path)

find-value-parentclj

(find-value-parent loc value)

generateclj

(generate generator-name data)

Generatorclj


generatorcljmultimethod


GeneratorPointclj


insert-at-pathclj

(insert-at-path loc path edits form)

modify-nodeclj

(modify-node loc {:keys [content modify] :as _point})

updates a node with rewrite-clj using point

updates a node with rewrite-clj using point
raw docstring

ModifyPathclj


NamespaceDestinationclj



PathDestinationclj


point-pathclj

(point-path point)

predclj

(pred p)

Navigate tree by pred

Navigate tree by pred
raw docstring

render-file-pointclj

(render-file-point {:keys [content] :as _point})

render-modify-pointclj

(render-modify-point point)

render-pointclj

(render-point {:keys [modify] :as point})

write-file-pointclj

(write-file-point point)

handle poitns that specify a whole file

handle poitns that specify a whole file
raw docstring

write-modify-pointclj

(write-modify-point point)

handle points that specify a modification

handle points that specify a modification
raw docstring

write-pointclj

(write-point {:keys [modify] :as point})

cljdoc builds & hosts documentation for Clojure/Script libraries