Write code generators that can be executed from the REPL
Write code generators that can be executed from the REPL
(->file n)Given a string or symbol, presumably representing a namespace, return a string that represents the equivalent file system path.
Given a string or symbol, presumably representing a namespace, return a string that represents the equivalent file system path.
(->ns f)Given a string or symbol, presumably representing a file path, return a string that represents the equivalent namespace.
Given a string or symbol, presumably representing a file path, return a string that represents the equivalent namespace.
(->subst-map substitutions)Given a hash map of substitution data, return a hash map of string
substitutions. For any unqualified keys that have string or symbol values,
compute a |ns version that could be used as a namespace and a |file
version that could be used as a filename. These are done fairly simply as seen
above.
Given a hash map of substitution data, return a hash map of string substitutions. For any unqualified keys that have string or symbol values, compute a `|ns` version that could be used as a namespace and a `|file` version that could be used as a filename. These are done fairly simply as seen above.
(append-child-newline loc _)(find-path loc path)(find-value-parent loc value)(generate generator-name data)(insert-at-path loc path edits form)(modify-node loc {:keys [content modify] :as _point})updates a node with rewrite-clj using point
updates a node with rewrite-clj using point
(point-path point)(render-file-point {:keys [content] :as _point})(render-modify-point point)(render-point {:keys [modify] :as point})(write-file-point point)handle poitns that specify a whole file
handle poitns that specify a whole file
(write-modify-point point)handle points that specify a modification
handle points that specify a modification
(write-point {:keys [modify] :as point})cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |